@@ -6,6 +6,7 @@ import warnings
 
 from lark.exceptions import UnexpectedToken
 from lark.lexer import Token, LexerThread
+from .lalr_parser_state import ParserState
 
 ###{standalone
 
@@ -14,7 +15,7 @@ class InteractiveParser:
 
     For a simpler interface, see the ``on_error`` argument to ``Lark.parse()``.
     """
-    def __init__(self, parser, parser_state, lexer_thread: LexerThread):
+    def __init__(self, parser, parser_state: ParserState, lexer_thread: LexerThread):
         self.parser = parser
         self.parser_state = parser_state
         self.lexer_thread = lexer_thread
@@ -63,15 +64,15 @@ class InteractiveParser:
 
         Calls to feed_token() won't affect the old instance, and vice-versa.
         """
+        return self.copy()
+
+    def copy(self, deepcopy_values=True):
         return type(self)(
             self.parser,
-            copy(self.parser_state),
+            self.parser_state.copy(deepcopy_values=deepcopy_values),
             copy(self.lexer_thread),
         )
 
-    def copy(self):
-        return copy(self)
-
     def __eq__(self, other):
         if not isinstance(other, InteractiveParser):
             return False
@@ -109,7 +110,7 @@ class InteractiveParser:
         conf_no_callbacks.callbacks = {}
         for t in self.choices():
             if t.isupper(): # is terminal?
-                new_cursor = copy(self)
+                new_cursor = self.copy(deepcopy_values=False)
                 new_cursor.parser_state.parse_conf = conf_no_callbacks
                 try:
                     new_cursor.feed_token(self.lexer_thread._Token(t, ''))
